global BetaC=1/1.04
global GammaC=1.5
use "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup_x2.dta", clear
use "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup2_x2.dta", clear
use "$path_epf_TS\wages_unemp_vol_data\main\emp_ene2_x2.dta", clear 

// 1.0 - Unemployment flows
use "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup2_x2.dta", clear
rename quint quintile_h
collapse popu, by(sexo educ zona2 sector_ind tr_edad2 quintile_h)
replace popu=ceil(popu)
save "$path_epf_TS\Popu_nrs.dta", replace


use "$path_epf_TS\NatAcc_data.dta", clear
g year = year(fecha)
g quarter=quarter(fecha)
sum fecha year quarter
sort year quarter
egen date = group(year quarter)
tsset date
g lag_C = L.c_tot
g lag_GDP = L.pib
g lag_Wage = L.w_r

g Cons_Pricing_K = ${BetaC}*( (c_tot/lag_C)^(-${GammaC}) )
g Cons_Pricing_K2 = ${BetaC}*( (ln(c_tot)/ln(lag_C))^(-${GammaC}) )
g GDP_Pricing_K2 = ${BetaC}*( (ln(pib)/ln(lag_GDP))^(-${GammaC}) )
g Wage_Pricing_K2 = ${BetaC}*( (ln(w_r)/ln(lag_Wage))^(-${GammaC}) )

g ConsPric_K_RealRate = 1/Cons_Pricing_K2 -1
g WagePric_K_RealRate = 1/Wage_Pricing_K2 -1
g ConsPric_K_RealRate_FW = F.ConsPric_K_RealRate
g WagePric_K_RealRate_FW = F.WagePric_K_RealRate
sum ConsPric_K_RealRate ConsPric_K_RealRate_FW WagePric_K_RealRate WagePric_K_RealRate_FW
pwcorr ConsPric_K_RealRate ConsPric_K_RealRate_FW WagePric_K_RealRate WagePric_K_RealRate_FW
sum Cons_Pricing_K Cons_Pricing_K2 ConsPric_K_RealRate GDP_Pricing_K2 Wage_Pricing_K2 WagePric_K_RealRate
pwcorr Cons_Pricing_K Cons_Pricing_K2 ConsPric_K_RealRate GDP_Pricing_K2 Wage_Pricing_K2 WagePric_K_RealRate

joinby year quarter using "$path_epf_TS\wages_unemp_vol_data\main\emp_ene2_x2.dta", unmatched(master) update
tab _merge
keep if _merge==3
drop _merge

pwcorr ConsPric_K_RealRate ConsPric_K_RealRate_FW WagePric_K_RealRate WagePric_K_RealRate_FW unemployed pr_layoffs pr_jobfind_inv

egen id = group(sexo zona2 tr_edad2 educ sector_ind quintile_h)
sum id
local idmax=r(max)
xtset id date

quietly {  
foreach x of varlist unemployed pr_layoffs pr_jobfind_inv {
g Beta_`x' = .
forvalues k=1(1)`idmax' {   
reg ConsPric_K_RealRate `x' if id==`k'
matrix b=e(b)
replace Beta_`x' = b[1,1] if id==`k'
} 
sum Beta_`x', d
replace Beta_`x' = max(r(p1), min(Beta_`x', r(p99)))
} 
}       
sum Beta_*, d
collapse Beta_*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_epf_TS\Beta_LaborFlows.dta", replace


// 2.0 - Wage volatility
use "$path_epf_TS\NatAcc_data.dta", clear
g year = year(fecha)
collapse c_tot pib, by(year)
g date=year
tsset date
g lag_C = L.c_tot
g lag_GDP = L.pib
g Cons_Pricing_K2 = ${BetaC}*( (ln(c_tot)/ln(lag_C))^(-${GammaC}) )
g GDP_Pricing_K2 = ${BetaC}*( (ln(pib)/ln(lag_GDP))^(-${GammaC}) )
g ConsPric_K_RealRate = 1/Cons_Pricing_K2 -1
joinby year using "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup2_x2.dta", unmatched(master) update  //emp_ing_ocup2_x2.dta emp_ing_ocup_x2.dta
tab _merge
keep if _merge==3
drop _merge
capture rename ln_ing_tot_ocup ln_ing_tot_ocup2
capture rename sd_ln_ing_tot_ocup sd_ln_ing_tot_ocup2
joinby year unemployed sexo zona2 tr_edad2 educ sector_ind quintile_ using "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup_x2.dta", unmatched(master) update 
tab _merge
keep if _merge==3
drop _merge
capture rename quintile quintile_h
keep if unemployed==0
egen id = group(sexo zona2 tr_edad2 educ sector_ind quintile_h)
sum id
local idmax=r(max)
xtset id date
quietly {  
foreach x of varlist ln_ing_tot_ocup sd_ln_ing_tot_ocup ln_ing_tot_ocup2 sd_ln_ing_tot_ocup2 {
g Beta_`x' = .
forvalues k=1(1)`idmax' {   
reg ConsPric_K_RealRate `x' if id==`k'
matrix b=e(b)
replace Beta_`x' = b[1,1] if id==`k'
} 
sum Beta_`x', d
replace Beta_`x' = max(r(p1), min(Beta_`x', r(p99)))
} 
egen Beta_ln_ing_tot_ocup3=rowmean(Beta_ln_ing_tot_ocup Beta_ln_ing_tot_ocup2)
*replace Beta_ln_ing_tot_ocup3=min(Beta_ln_ing_tot_ocup3,Beta_ln_ing_tot_ocup, Beta_ln_ing_tot_ocup2) if Beta_ln_ing_tot_ocup3>=0 & Beta_ln_ing_tot_ocup2>0 & Beta_ln_ing_tot_ocup>0
*replace Beta_ln_ing_tot_ocup3=max(Beta_ln_ing_tot_ocup3,Beta_ln_ing_tot_ocup, Beta_ln_ing_tot_ocup2) if Beta_ln_ing_tot_ocup3<0 & Beta_ln_ing_tot_ocup2<0 & Beta_ln_ing_tot_ocup>0

egen Beta_sd_ln_ing_tot_ocup3=rowmean(Beta_sd_ln_ing_tot_ocup Beta_sd_ln_ing_tot_ocup2)
*replace Beta_sd_ln_ing_tot_ocup3=min(Beta_sd_ln_ing_tot_ocup3,Beta_sd_ln_ing_tot_ocup, Beta_sd_ln_ing_tot_ocup2) if Beta_sd_ln_ing_tot_ocup3>=0 & Beta_sd_ln_ing_tot_ocup2>0 & Beta_sd_ln_ing_tot_ocup>0
*replace Beta_sd_ln_ing_tot_ocup3=max(Beta_sd_ln_ing_tot_ocup3,Beta_sd_ln_ing_tot_ocup, Beta_sd_ln_ing_tot_ocup2) if Beta_sd_ln_ing_tot_ocup3<0 & Beta_sd_ln_ing_tot_ocup2<0 & Beta_sd_ln_ing_tot_ocup<0
}       
sum Beta_ln*, d
sum Beta_sd*, d
collapse Beta_*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_epf_TS\Beta_WageVol.dta", replace

joinby sexo zona2 tr_edad2 educ sector_ind quintile_h using "$path_epf_TS\Beta_LaborFlows.dta", unmatched(both) update
tab _merge
drop _merge Beta_ln_ing_tot_ocup- Beta_sd_ln_ing_tot_ocup2
sum Beta_*
pwcorr Beta_*
save "$path_epf_TS\Beta_WageVol_LaborFlows.dta", replace



// 3.0 Pension Fund Betas
clear
import excel "C:\DAT\EFH\Proyectos\2020_EPF\data_TS\wages_unemp_vol_data\fund_returns\rentabilidad_real_mensual.xls", sheet("Hoja1") firstrow
destring _all, replace force
drop I-K
g quarter=ceil(month/3)
replace r_C=r_C/100
collapse r_C, by(year quarter)
joinby year quarter using "$path_epf_TS\wages_unemp_vol_data\main\emp_ene2_x2.dta", unmatched(master) update
tab _merge
keep if _merge==3
drop _merge
egen id = group(sexo zona2 tr_edad2 educ sector_ind quintile_h)
egen date = group(year quarter)
sum id
local idmax=r(max)
xtset id date
quietly {  
foreach x of varlist unemployed pr_layoffs pr_jobfind_inv {
g BetaPF_`x' = .
forvalues k=1(1)`idmax' {   
reg r_C `x' if id==`k'
matrix b=e(b)
replace BetaPF_`x' = b[1,1] if id==`k'
} 
sum BetaPF_`x', d
replace BetaPF_`x' = max(r(p1), min(BetaPF_`x', r(p99)))
} 
}       
sum BetaPF_*, d
collapse BetaPF_*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_epf_TS\BetaPF_LaborFlows.dta", replace

clear
import excel "C:\DAT\EFH\Proyectos\2020_EPF\data_TS\wages_unemp_vol_data\fund_returns\rentabilidad_real_mensual.xls", sheet("Hoja1") firstrow
destring _all, replace force
replace r_C=r_C/100
collapse r_C, by(year)
joinby year using "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup2_x2.dta", unmatched(master) update  
tab _merge
keep if _merge==3
drop _merge
capture rename ln_ing_tot_ocup ln_ing_tot_ocup2
capture rename sd_ln_ing_tot_ocup sd_ln_ing_tot_ocup2
joinby year unemployed sexo zona2 tr_edad2 educ sector_ind quintile_ using "$path_epf_TS\wages_unemp_vol_data\main\emp_ing_ocup_x2.dta", unmatched(master) update 
tab _merge
keep if _merge==3
drop _merge
capture rename quintile quintile_h
keep if unemployed==0
egen id = group(sexo zona2 tr_edad2 educ sector_ind quintile_h)
g date=year
sum id
local idmax=r(max)
xtset id date
quietly {  
foreach x of varlist ln_ing_tot_ocup sd_ln_ing_tot_ocup ln_ing_tot_ocup2 sd_ln_ing_tot_ocup2 {
g BetaPF_`x' = .
forvalues k=1(1)`idmax' {   
reg r_C `x' if id==`k'
matrix b=e(b)
replace BetaPF_`x' = b[1,1] if id==`k'
} 
sum BetaPF_`x', d
replace BetaPF_`x' = max(r(p1), min(BetaPF_`x', r(p99)))
} 
egen BetaPF_ln_ing_tot_ocup3=rowmean(BetaPF_ln_ing_tot_ocup BetaPF_ln_ing_tot_ocup2)
egen BetaPF_sd_ln_ing_tot_ocup3=rowmean(BetaPF_sd_ln_ing_tot_ocup BetaPF_sd_ln_ing_tot_ocup2)
}       
sum BetaPF_ln*, d
sum BetaPF_sd*, d
collapse BetaPF_*, by(sexo zona2 tr_edad2 educ sector_ind quintile_h)
save "$path_epf_TS\BetaPF_WageVol.dta", replace

joinby sexo zona2 tr_edad2 educ sector_ind quintile_h using "$path_epf_TS\BetaPF_LaborFlows.dta", unmatched(both) update
tab _merge
drop _merge BetaPF_ln_ing_tot_ocup-BetaPF_sd_ln_ing_tot_ocup2
sum BetaPF_*
pwcorr BetaPF_*
save "$path_epf_TS\BetaPF_WageVol_LaborFlows.dta", replace

joinby sexo educ zona2 sector_ind tr_edad2 quintile_h using "$path_epf_TS\Beta_WageVol_LaborFlows.dta", unmatched(master) update
tab _merge
drop _merge
sum BetaPF_unemployed BetaPF_sd_ln_ing_tot_ocup3 Beta_unemployed Beta_sd_ln_ing_tot_ocup3, d
pwcorr BetaPF_unemployed BetaPF_sd_ln_ing_tot_ocup3 Beta_unemployed Beta_sd_ln_ing_tot_ocup3
joinby sexo educ zona2 sector_ind tr_edad2 quintile_h using "$path_epf_TS\Popu_nrs.dta", unmatched(master) update
tab _merge
drop _merge
sum BetaPF_unemployed BetaPF_sd_ln_ing_tot_ocup3 Beta_unemployed Beta_sd_ln_ing_tot_ocup3 [fw=popu], d 
pwcorr BetaPF_unemployed BetaPF_sd_ln_ing_tot_ocup3 Beta_unemployed Beta_sd_ln_ing_tot_ocup3 [fw=popu]
foreach num of numlist 5 10 25 50 75 90 95 {
foreach x of varlist BetaPF_unemployed BetaPF_sd_ln_ing_tot_ocup3 Beta_unemployed Beta_sd_ln_ing_tot_ocup3 {
g `x'_p`num' = `x'
}
}
collapse (p5) *p5 (p10) *p10 (p25) *p25 (p50) *p50 (p75) *p75 (p90) *p90 (p95) *p95 [fw=popu]
g constant=1
reshape long BetaPF_unemployed_p BetaPF_sd_ln_ing_tot_ocup3_p Beta_unemployed_p Beta_sd_ln_ing_tot_ocup3_p, i(constant) j(Percentile)
export excel using "$path_g1\\Betas_wagevol_stats.xlsx", firstrow(variables) nolabel replace

