/* 01-12 - Gasto de consumo individual de los hogares
01 - Alimentos y bebidas no alcohólicas
02 - Bebidas alcohólicas, tabaco y narcóticos
03 - Ropa y calzado
04 - Vivienda , agua , electricidad , gas y otros combustibles
05 - Mobiliario , equipamiento del hogar y mantenimiento rutinario de los hogares
06 - Salud
07 - Transporte
08 - Comunicación
09 - Recreación y cultura
10 - Educación
11 - Restaurantes y hoteles
12 - Otros bienes y servicios */

/* Cerletti and Pijoan-Mas 2017: Given these assumptions, we think of durable goods as cars,
furniture, home appliances, and the like, but we exclude housing from our main exercise.
We classify the different expenditure categories in the CEX as
either durable or nondurable. Durable goods include cloth, jewellery, furniture, household
appliances, vehicles and spare parts, books, and sport and recreational equipment, but
exclude housing, which is included in A. Nondurables include food and other household
supplies, household utilities, services, public transport fees, fuel and tolls expenditures.10
We also use aggregate data on durables from the 2011 revision of Fixed Reproducible
Tangible Wealth by the Bureau of Economic Analysis. Our definition of durables in the
aggregate data closely follows the one in the micro data, and it’s basically obtained from
subtracting therapeutic equipment from the total stock of consumer durables.   */

use "$path_epf\\CCIF_VIII_EPF.dta", clear
sort D G C SC P       //edit GLOSA D G C SC P CCIF if D=="09" // "03"  "04" "05"  "06" "07" 
g ndur=regexm(GLOSA, "ALQUIL")
replace ndur=1 if CCIF=="04.5.4.01.02"
replace ndur=1 if D=="06" 
foreach name in "SALUD" "APARA" "ARTEF" "EQUIP" "CIRUG" "TESIS" "AMBULATORI" "CONSULTA" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="06" 
}
replace ndur=1 if D=="07" 
foreach name in "ADQUIS" "VEH" "AUTOM" "MOTOCI" "BICIC" "ANIMAL" "EQUIP" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="07" 
}
replace ndur=1 if D=="08" 
foreach name in "EQUIP" "FONOS FIJO" "VILES" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="08" 
}
replace ndur=1 if D=="10" 
foreach name in "ADMIS" "CUOTA" "EXAM" "NO MENSUA" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="10" 
}
replace ndur=1 if D=="11" 
foreach name in "COMPLEJ" "HOSTA" "CAMPIN" "HOTELE" "CABA" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="11" 
}
replace ndur=1 if D=="12" 
foreach name in "RELOJ" "FUNER" "TATUA" "PIEDRA" "JOY" "BISU" "MALET" "BOLS" "MOCHI" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="12" 
}
foreach name in "ARRIEN" "SERVIC" "SUMINI" "GASTOS COMUNES" "ELECTRICI" "GAS" "COMBUSTIB" "CARB" "LEN" "BASUR" "ILUMINAC" "MPARAS" {
replace ndur=regexm(GLOSA, "`name'") if ndur!=1
}
foreach name in "CONSERV" "MATER" "SERVICIO DE ELECTRICIS" "SERVICIO DE GASF" "SERVICIO DE P" "SERVICIO DE S" "SERVICIO DE L" "SERVICIO DE AL" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="04" 
}
foreach name in "MUEBL" "ARTEF" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="05" 
}
foreach name in "HOSPIT" {
replace ndur=. if regexm(GLOSA, "`name'")==1 & D=="06" 
}
foreach name in "LIMPIE" "DIE SEL" "PETR LEO" "DESINFE" "PAPEL" "FARMAC" "MEDICA" "LUBRIC" "NO DUR" "AROMA" "BOLSA" "INSECT" "RESTAURANT" {
replace ndur=regexm(GLOSA, "`name'") if ndur!=1  // "PARA EL HOGAR PEQUE" "PEQUE"
}
foreach name in "ORDINARIA DEL HOGAR" "ARRIEND" "COSTU" "ACCESORIOS EL" "DISPOSITIVOS EL" "ILUMIN" "CULTURA" "ENTRAD" "CLAS" "JUEG" {
replace ndur=regexm(GLOSA, "`name'") if ndur!=1  // "PARA EL HOGAR PEQUE" "PEQUE"
}
foreach name in "INSTALACI" {
replace ndur=. if regexm(GLOSA, "`name'")==1
}
replace ndur=1 if D=="09" & (G=="4" | G=="5" | G=="6")
replace ndur=1 if D=="09" & G=="3" & (C=="3" | C=="4" | C=="5")
replace ndur=1 if D=="09" & G=="1" & C=="4"
g semidur=1 if ndur!=1 & (D=="06" | D=="03"  | D=="10" | D=="11" | D=="12")
foreach name in "APAR" "CIRU" "ARTEF" "TESIS" "EQUIP" "PARA MEDI"  {
replace semidur=. if regexm(GLOSA, "`name'")==1 & D=="06"
}
replace semidur=1 if D=="09" & regexm(GLOSA, "PAQUETES TUR")==1
replace semidur=1 if D=="09" & regexm(GLOSA, "VIAJE")==1
replace ndur=. if semidur==1 //edit GLOSA D G C SC P CCIF if D=="09" & ndur!=1 & semidur==1 //edit GLOSA D G C SC P CCIF if D=="06" & ndur!=1 & semidur!=1 
g DURABLES = 1 if ndur!=1 & semidur!=1 & (D=="04" | D=="05" | D=="06" | D=="07" | D=="08" | D=="09")
g SEMI_DURABLES = 1 if ndur!=1 & semidur==1 & (D=="03" | D=="06" | D=="09" | D=="10" | D=="11" | D=="12")
g CCIF_nr=subinstr( CCIF ,".","",6) // edit GLOSA D G C SC P CCIF if D=="09" & ndur!=1 // "03"  "04" "05"  "06" "07" 
destring CCIF_nr, replace force
save "$path_epf\\CCIF_VIII_EPF_SDur_Dur.dta", replace
keep if DURABLES==1
keep CCIF_nr
save "$path_epf\\CCIF_VIII_EPF_Dur.dta", replace
use "$path_epf\\CCIF_VIII_EPF_SDur_Dur.dta", clear
keep if SEMI_DURABLES==1
keep CCIF_nr
save "$path_epf\\CCIF_VIII_EPF_SDur.dta", replace
joinby CCIF_nr using "$path_epf\\CCIF_VIII_EPF_Dur.dta", unmatched(both) update
tab _merge   // Good! Semi-Durables (197 products) and Durables (328 products) are mutually exclusive

use "$path_epf\\CCIF_VIII_EPF_SDur_Dur.dta", clear
drop if DURABLES==1  |  SEMI_DURABLES==1
g Servicio=regexm(GLOSA, "ALQUIL")
replace Servicio=1 if D=="06" | D=="07" | D=="08" | D=="09"  | D=="10" | D=="11" | D=="12" 
keep if Servicio==1
keep CCIF_nr
save "$path_epf\\CCIF_VIII_EPF_Serv.dta", replace

use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear   //   2016-2017  //
egen folio = group(FOLIO_V FOLIO)
g CCIF_nr=subinstr( CCIF ,".","",6)
destring CCIF_nr, replace force
joinby CCIF_nr using "$path_epf\\CCIF_VIII_EPF_Serv.dta", unmatched(both) update
tab _merge
keep if _merge==3  //drop _merge
collapse (sum) GASTO, by(folio)
rename GASTO Servicio 
save "$path_s0\data_results\\gastos_hogar_Serv.dta", replace 
use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear   //   2016-2017  //
egen folio = group(FOLIO_V FOLIO)
collapse (sum) GASTO, by(folio D)   // [fw=FE]
destring D, replace force
drop if D==.
rename GASTO GASTO_D
reshape wide GASTO_D, i(folio) j(D)
rename GASTO_D6 gtos_medicos
rename GASTO_D10 educacion_gasto
keep folio gtos_medicos educacion_gasto
save "$path_s0\data_results\\gastos_hogar_Salud_Educacion.dta", replace  //"$path_s0\\data_EPF\2017\gastos_hogar.dta"

use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear  
egen folio = group(FOLIO_V FOLIO)
keep if D=="04" & G=="1"   // Arriendo Gasto
collapse (sum) GASTO, by(folio)
rename GASTO arriendo_gasto  // gasto_tot gasto_durable gasto_no_durable
save "$path_s0\data_results\\gastos_hogar_ArriendoG.dta", replace 
use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear  
egen folio = group(FOLIO_V FOLIO)
keep if CCIF=="04.2.1.01.01" | CCIF=="04.2.2.01.01" | CCIF=="04.2.2.01.02"  // Arriend Imputado
collapse (sum) GASTO, by(folio)
rename GASTO arriendo_imputado  // gasto_tot gasto_durable gasto_no_durable
save "$path_s0\data_results\\gastos_hogar_ArriendoI.dta", replace 
use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear   //   2016-2017  //
egen folio = group(FOLIO_V FOLIO)
g CCIF_nr=subinstr( CCIF ,".","",6)
destring CCIF_nr, replace force
joinby CCIF_nr using "$path_epf\\CCIF_VIII_EPF_SDur.dta", unmatched(both) update
tab _merge
keep if _merge==3  //drop _merge
collapse (sum) GASTO, by(folio)
rename GASTO  gasto_semi_durable  // gasto_tot gasto_durable gasto_no_durable
save "$path_s0\data_results\\gastos_hogar_DurSDur_Tot.dta", replace 
use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear   
egen folio = group(FOLIO_V FOLIO)
g CCIF_nr=subinstr( CCIF ,".","",6)
destring CCIF_nr, replace force
joinby CCIF_nr using "$path_epf\\CCIF_VIII_EPF_Dur.dta", unmatched(both) update
tab _merge
keep if _merge==3  //drop _merge
collapse (sum) GASTO, by(folio)
rename GASTO  gasto_durable0  
joinby folio using "$path_s0\data_results\\gastos_hogar_DurSDur_Tot.dta", unmatched(both) update
tab _merge
drop _merge
save "$path_s0\data_results\\gastos_hogar_DurSDur_Tot.dta", replace 
use "$path_epf\BASE_GASTOS_VIII_EPF.dta", clear   
egen folio = group(FOLIO_V FOLIO)
collapse (sum) GASTO, by(folio)
rename GASTO  gasto_tot  // gasto_tot gasto_durable gasto_no_durable
joinby folio using "$path_s0\data_results\\gastos_hogar_DurSDur_Tot.dta", unmatched(both) update
tab _merge
drop _merge
joinby folio using "$path_s0\data_results\\gastos_hogar_ArriendoI.dta", unmatched(both) update 
tab _merge
drop _merge
joinby folio using "$path_s0\data_results\\gastos_hogar_ArriendoG.dta", unmatched(both) update 
tab _merge
drop _merge
joinby folio using "$path_s0\data_results\\gastos_hogar_Salud_Educacion.dta", unmatched(both) update 
tab _merge
drop _merge
joinby folio using "$path_s0\data_results\\gastos_hogar_Serv.dta", unmatched(both) update 
tab _merge
drop _merge
g gasto_durable = max(0,gasto_durable) + (1/2)*max(0,gasto_semi_durable)
g gasto_no_durable = max(0,gasto_tot)-max(0,gasto_durable)
drop if folio==.
foreach var of varlist gasto_tot- gasto_no_durable {
replace `var'=max(0,`var')
}
save "$path_s0\data_results\\gastos_hogar_DurSDur_Tot.dta", replace 
sum
