// Multivariate analysis of EPF family's income and consumption data
capture log close
set more off
global path_epf2 "$path_epf\\data_results\"
global path_epf3 "$path_epf\\graphs\"
global factor_op "factor_all"
global path_s1 "$path_epf2"  //global path_s3 "D:\DAT\DPF\Analisis Financiero\Sector Hogares\EFH\Proyectos\2010_Household Risk\simulation_time"

*use "$path_epf2\EPF_MLE_${data_save_emp}.dta", clear
use "$path4b\expenditures_${data_save_emp}_all.dta", clear
g year_epf = year
rename ytot_ind_or ytot_ind
g constant = 1
g actividad = sector_ind
egen folio_hogar = group(hogar year)
keep quintile_h factor_all ted* tr_ed* ///
layoffs_sect jobfind unemp_sect quintile_renta numh rr_inc_sect sd_ln_inc_sect ///
ytot_ind ytot_p_h num_men num_adult num_sen edad ytoth_pi ///
sexo zona2 sector_ind tr_edad2 educ quintile_renta desem ocup ///
year_epf foli* a1 a2 constant ytoth yai yaotp yact ytoth actividad ytoth_cons
rename ytoth_cons original_ytoth_cons
g original_ytot_p_h = ytot_p_h
save "$path_s1\EPF_risk0.dta", replace

// Create EFH with different unemployment and income risk rates for each year-quarter
quietly {
forv yr==1996/2017 {
forv q==1/4 {
use "$path_s1\EPF_risk0.dta", clear
g year = min(2014,`yr')
g quarter = `q'
capture drop layoffs_sect jobfind unemp_sect rr_inc_sect sd_ln_inc_sect ytot_p_h //or rename ytot_ind ori_ytot_ind

// Probability of unemployment
layoff_jobfind0 12
if `yr'>2014 {
g year_un = `yr'
g quarter_un = `q'
capture drop _merge
joinby year_un quarter_un using "$path_bs_do\adj_un_ine.dta", unmatched(both) update
sum unemployed [fw=factor_all]
local adj_un0 = r(mean)
sum un_ine [fw=factor_all]
local adj_un0 = r(mean)/`adj_un0'
replace unemployed = unemployed*`adj_un0'
replace layoffs_sect = layoffs_sect*`adj_un0'
replace unemp_sect = unemp_sect*`adj_un0'
drop year_un quarter_un un_ine _merge
}
rename unemployed pr_unemployed
g unemployed = desem 
capture drop _merge
income_shock0 12
run "$path_bs_do\p_income" // Calculates Permanent Income of the Family
drop unemployed  
capture drop _merge
replace year = `yr'
keep if a1==1
drop aux_layoffs-pr_unemp_i ln_ing_tot_ocup-rr_inc2_i sd_ln_inc_w0-sd_ln_inc2_i sd_inc_w0-sd_inc_sect a1 a2 constant actividad 
if `yr'==1996 & `q'==1 {
save "$path_s1\EPF_risk_yq2.dta", replace
}
else {
joinby folio year quarter using "$path_s1\EPF_risk_yq2.dta", unmatched(both) update
capture drop _merge
save "$path_s1\EPF_risk_yq2.dta", replace
}
}
}
}
g ytoth_cons = original_ytoth_cons*(ytot_p_h/original_ytot_p_h)
keep foli* year quarter layoffs_sect jobfind unemp_sect rr_inc_sect sd_ln_inc_sect ytot_p_h ytot_ind ytoth_cons
foreach v of varlist year quarter layoffs_sect jobfind unemp_sect rr_inc_sect sd_ln_inc_sect ytot_p_h ytot_ind ytoth_cons { 
rename `v' `v'_v
}
save "$path_s1\EPF_risk_yq2.dta", replace

