capture log close
set more off
global path2_esi "D:\DAT\DPF\Analisis Financiero\Sector Hogares\EFH\Proyectos\2010_Household Risk\household_risk\empleo\panel_esi"

// New variables - 2007 coding
*ae // ae - nr of years of education (0-20, 99)
*estcony  // estcony, civil state - married or single (0-5)
*size_estab  // p09 - size of the company (0-3)
*usual_weekly_hours  // p10 - usual weekly work hours - 0-99
*eff_weekly_hours  // effectively worked hours last week
*other_jobs // More than one job    *curso // highest grade completed

// 1 - Create all year Panel ESI of workers
forv year=1991/2012 {   // Create Panel sample
quietly {	
if `year'!=1994 & `year'!=1995 & `year'!=1996 & `year'!=2006 & `year'!=2007 & `year'!=2010 {  // some years have no panel component

// Variables to add in each year (Other variables: ae, curso, estado_civil, size of company, usual hours worked, hours effectively worked??)
local vars_year0 "wage_main wage_all wage_main_hh wage_all_hh cp_total"
local vars_year "ae estcony size_estab usual_weekly_hours eff_weekly_hours other_jobs zona* cp_total wage* nr_hh_members ing_tot ytoth decil_h quintile_h labor_force_p employed unemployed actividad sector_ind duration_unem layoffs"
*egen id_person = group(id_hogar region sexo edad nivel parentesco), missing // use educ or nivel   * `vars_year' `vars_year0' 
local year_ref = `year'-1
local vars_panel_id "estcony_`year_ref' zona2_`year_ref' wage_all_hh_`year_ref' nr_hh_members_`year_ref' ing_tot_`year_ref' ytoth_`year_ref' labor_force_p_`year_ref' unemployed_`year_ref'"
local vars_panel "sexo edad educ parentesco factor* id_hogar2 id_person2 *`year' *`year_ref'"
local vars_reg "sexo edad i.(educ) i.(parentesco) wage_main_hh_`year' ytoth_`year' nr_hh_members_`year' labor_force_p_`year' employed_`year'"
local vars_reg_hh "sexo edad i.(educ) wage_main_hh_`year' ytoth_`year' nr_hh_members_`year' labor_force_p_`year' employed_`year'"

use "$path2_esi\panel_esi_`year'.dta", clear
esi_format `year' `year_ref'  // Format each year
if `year'>1991 {
append using "$path_epf\data_results\panel_esi_allFLP.dta"  // _`i'_${data_save_emp}
}
compress
save "$path_epf\data_results\panel_esi_allFLP.dta", replace  // _`i'_${data_save_emp}
}
}
}
//
use "$path_epf\data_results\panel_esi_allFLP.dta", clear
g constant = 1
order id* year quar* constant sexo factor_esi educ zona2 quintile_h sector_ind actividad tr_edad tr_edad2 quintile_renta, first
/*  capture drop id_worker id_gr pop_gr
g id_worker = _n 
egen id_gr = group(year factor_esi)  // g id_gr2 = ceil(id_gr/4) //g id_gr2 = 1
bysort id_gr: egen pop_gr = total(factor_esi)
// Observations here are of workers, not households so it is ok to not use cluster(id_hogar)
bsample, strata(year id_gr) // cluster(id_hogar) idcluster(id_obs)  //bsample, cluster(id_hogar) strata(year id_gr2) idcluster(id_bs)
rename id_hogar id_hogar_original 
egen id_hogar = group(id_hogar_original id_bs) // 
drop id_gr pop_gr  // id_bs nr_reps */
save "$path_epf\data_results\panel_esi_allFLP.dta", replace 


// 2 - Do regressions on Panel ESI of workers using all years
use "$path_epf\data_results\panel_esi_allFLP.dta", clear
drop if labor_force_p_t1==.  |  labor_force_p_t0==.
drop if grupo_edad<=5
drop if grupo_edad>=14
drop if educ==.  |  tr_edad2==.
replace numh_t0 = min(7, numh_t0, numh_t1) if numh_t0<.
*replace numh_t0 = min(5, numh_t0, numh_t1) if numh_t0<.
replace numh_t0 = 1 if numh_t0==.
tab grupo_edad tr_edad
sum lab* emp* une* id*
tab employed_t1 unemployed_t1  // tab employed_t0 unemployed_t0
sum wage_t0 if wage_main_t0>0  // wage_main_t1, wage_main_t0 seem to be more reliable variables
pwcorr wage_t0 wage_main_t0 if wage_main_t0>0  // pwcorr wag* if wage_main_t0>0 & wage_main_t1>0
sum wage* ln*  if wage_main_t0>0 & wage_main_t1>0
g ln_labor_earnings_t0 = max(  ln(wage_main_t0), ln_wage_t0 , ln(wage_t0) )
egen grupo_edad2=group(grupo_edad)

log using "$path4b\\esi_panel_allFLP_regs.log", replace
tab year
tab grupo_edad2
tab numh_t0
bysort sexo: sum labor_force_p_t1 labor_force_p_t0 wage_drop wage_increase [fw=factor_esi]
bysort year: sum labor_force_p_t1 labor_force_p_t0 if sexo==2 [fw=factor_esi]
bysort year: sum labor_force_p_t1 labor_force_p_t0 if sexo==1 [fw=factor_esi]
// Women
bysort labor_force_p_t0: sum labor_force_p_t1 if sexo==2 [fw=factor_esi]
probit labor_force_p_t1 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==2 [pw=factor_esi]  // sector_ind (may or not be included)
predict LFP_Women_PSS if sexo==2 
probit labor_force_p_t1 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==2 & labor_force_p_t0==1 [pw=factor_esi]  // sector_ind (may or not be included)
predict LFP_Women_P1 if sexo==2 & labor_force_p_t0==1
probit labor_force_p_t1 ln_labor_earnings_t0 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==2 & labor_force_p_t0==1 [pw=factor_esi] // sector_ind (may or not be included)
outreg2 using "$path_epf\\data_results\\LFP_ols.xls", replace
matrix bc0 = e(b)'
svmat double bc0, name(probit_LFP_Wt1)
probit labor_force_p_t1 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==2 & labor_force_p_t0==0 [pw=factor_esi]  // sector_ind (not included, because it is unreported in t0)
outreg2 using "$path_epf\\data_results\\LFP_ols.xls", append
predict LFP_Women_P0 if sexo==2 & labor_force_p_t0==0
sum LFP_Women_PSS LFP_Women_P1 LFP_Women_P0, d
reg ln_wage_t1 ln_wage_t0 i.(year) i.(zona2 educ grupo_edad2) if sexo==2 [pw=factor_esi] // quintile_h sector_ind sexo grupo_edad grupo_edad2 tr_edad tr_edad2 quintile_renta quintile_h
matrix bc0 = e(b)'
svmat double bc0, name(ols_LnWage_Wt1)
reg ln_wage_t1 i.(year) i.(zona2 quintile_h educ grupo_edad2 sector_ind) if sexo==2 [pw=factor_esi]
predict ln_wage_t1_Women if sexo==2
reg wage_drop i.(year) i.(zona2 quintile_h educ grupo_edad2) if sexo==2  [pw=factor_esi]
reg wage_increase i.(year) i.(zona2 quintile_h educ grupo_edad2) if sexo==2 [pw=factor_esi]

// Men
bysort labor_force_p_t0: sum labor_force_p_t1 if sexo==1 [fw=factor_esi]
probit labor_force_p_t1 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==1 & labor_force_p_t0==1 [pw=factor_esi]  // sector_ind
predict LFP_Men_P1 if sexo==1 & labor_force_p_t0==1
probit labor_force_p_t1 ln_labor_earnings_t0 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==1 & labor_force_p_t0==1 [pw=factor_esi]  // sector_ind (may or not be included)
outreg2 using "$path_epf\\data_results\\LFP_ols.xls", append
matrix bc0 = e(b)'
svmat double bc0, name(probit_LFP_Mt1)
probit labor_force_p_t1 i.(year) i.(numh_t0 zona2 educ grupo_edad2) if sexo==1 & labor_force_p_t0==0 [pw=factor_esi] // sector_ind
outreg2 using "$path_epf\\data_results\\LFP_ols.xls", append
predict LFP_Men_P0 if sexo==1 & labor_force_p_t0==0
sum LFP_Men_P1 LFP_Men_P0, d
reg ln_wage_t1 ln_wage_t0 i.(year) i.(zona2 educ grupo_edad2) if sexo==1 [pw=factor_esi] // quintile_h  sector_ind sexo tr_edad tr_edad2
matrix bc0 = e(b)'
svmat double bc0, name(ols_LnWage_Mt1)
reg ln_wage_t1 i.(year) i.(zona2 quintile_h educ grupo_edad2 sector_ind) if sexo==1 [pw=factor_esi]
predict ln_wage_t1_Men if sexo==1
reg wage_drop i.(year) i.(zona2 quintile_h educ grupo_edad2) if sexo==1  [pw=factor_esi]
reg wage_increase i.(year) i.(zona2 quintile_h educ grupo_edad2) if sexo==1 [pw=factor_esi]

save "$path_epf\data_results\panel_esi_allFLP2.dta", replace 
log close
use "$path_epf\data_results\panel_esi_allFLP2.dta", clear
g population_strata = 1
collapse (sum) population_strata [fw=factor_esi], by(educ zona2 quintile_h sector_ind grupo_edad2)
save "$path_epf\data_results\panel_esi2_population.dta", replace
use "$path_epf\data_results\panel_esi_allFLP2.dta", clear
g population_strata = 1
collapse (sum) population_strata [fw=factor_esi], by(sexo educ zona2 quintile_h sector_ind grupo_edad2)
save "$path_epf\data_results\panel_esi2_population_sexo.dta", replace

// 3 - Create Summary data
local var_list_esi0 "constant"
local var_list_esi1 "zona2 grupo_edad2 educ quintile_h"  //grupo_edad 
local var_list_esi2 "zona2 sector_ind grupo_edad2 educ quintile_h"
local var_list_esi3 "zona2 grupo_edad2 educ"
foreach i of numlist 0 1 2 3 {
use "$path_epf\data_results\panel_esi_allFLP2.dta", clear
collapse (mean) LFP* ln_wage_t1_Women ln_wage_t1_Men [fw=factor_esi], by("`var_list_esi`i''")
save "$path_epf\data_results\LFP_`i'.dta", replace
}
use "$path_epf\data_results\panel_esi_allFLP2.dta", clear
keep probit* ols*
drop if ols_LnWage_Mt1==. & ols_LnWage_Wt1==. & probit_LFP_Wt1==. & probit_LFP_Mt1==.
foreach i of numlist 1991 1992/1993 1997/2005 2008/2009 2011 {  //Keep just 2012 dummy
drop if _n==2
}
save "$path_epf\data_results\LFP_Wage_coefs.dta", replace
