clear 
import excel "$path4b\\Chile_CELADE2013_sel.xlsx", sheet("Population_total") firstrow  // "PopB" "PopMen" "PopWomen"
drop if grupo_edad==.
rename grupo_edad grupo_edad2
drop Year
foreach num of numlist 1996(1)2016 2018(1)2100 { // Standardiz everything for 2017
replace y`num' = y`num'/y2017
}
replace y2017 = 1
reshape long y, i(sexo grupo_edad2) j(YearR)
rename y PopEdSexo
save "$path_epf2\Chile_PopR.dta", replace

use "$path_epf2\Chile_CELADE_lifeexp.dta", clear
rename year yearR
rename life_expectancy60 life_expectancy60R
save "$path_epf2\Chile_CELADE_lifeexpR.dta", replace

use "$path4b\expenditures_${data_save_emp}_all3.dta", clear  // age_lifetime_income_ratio_data.d
g grupo_edad2 = ceil(min(101,(1+edad))/5) if edad>=0  // Age dummies
drop if grupo_edad2==.
replace educ=1 if educ==.
g YearR=2022  // 2020
sum YearR
joinby YearR sexo grupo_edad2 using "$path_epf2\Chile_PopR.dta", unmatched(master) update
tab _merge
drop _merge
sum year edad parentesco CB* life_expectancy60 life_expectancy0 *male* 
replace edad=. if edad<=0
replace tr_edad=6 if edad>64 & tr_edad==. & parentesco<=3
replace tr_edad=-1 if tr_edad==. & parentesco<=3   //sum PCS* LF* IL*
rename tr_edad tr_edad0
rename tr_edad2 tr_edad20
g tr_edad=0
replace tr_edad=1 if edad>=15 & edad<25
replace tr_edad=2 if edad>=25 & edad<35
replace tr_edad=3 if edad>=35 & edad<45
replace tr_edad=4 if edad>=45 & edad<55
replace tr_edad=5 if edad>=55 & edad<65
replace tr_edad=5 if edad>=65   // Tramos de edad 2 - Young, Middle Age, Old
g tr_edad2 = tr_edad
recode tr_edad2 1/2=1 3/4=2 5=3
tab tr_edad tr_edad0
tab tr_edad2 tr_edad20
quietly {  
capture drop pr_unemp_*
foreach x of varlist PCS* LF* IL* unemp_sect pr_unemp pr_layoffs layoffs_sect rr_inc rr_inc_sect {
bysort sexo educ tr_edad: egen rr=mean(`x')     //grupo_edad tr_edad
g rr1 = rr if tr_edad>=1 & tr_edad<=2
bysort sexo educ: egen rr2=mean(rr1) 
replace `x'=rr2 if `x'==.
drop rr rr1 rr2
}
}
g uf_q4 = 13956.1	if year==1997
replace uf_q4 = 19433.5	if year==2007
replace uf_q4 = 22783.5	if year==2012
replace uf_q4 = 26798	if year==2017   //sum PCS* LF* IL*
g minW = 264000*(uf_q4/26798)  // https://es.wikipedia.org/wiki/Anexo:Salario_m%C3%ADnimo_en_Chile // https://www.dt.gob.cl/portal/1628/w3-article-60141.html
sum Female_LFP Male_LFP Female_ILFP Male_ILFP ingreso_trabajo_dependiente ingreso_trabajo_independiente //ILFP_male_spouse ILFP_female_spouse
g ILFP2=(ingreso_trabajo_independiente>0 & ingreso_trabajo_independiente<. & ingreso_trabajo_dependiente<minW) 
replace ILFP2=(ingreso_trabajo_independiente>0 & ingreso_trabajo_independiente<. & ingreso_trabajo_dependiente==.) if ILFP2==.  | ILFP2==0
egen ingreso_trabajo = rowmax(ingreso_trabajo_independiente ingreso_trabajo_dependiente)
g LFP2=(ingreso_trabajo>0 & ingreso_trabajo<.) 
pwcorr ILFP2 ILFP Male_LFP Male_ILFP if male_dummy==1
pwcorr ILFP2 ILFP Female_LFP Female_ILFP if female_dummy==1
tab ILFP2 ILFP
sum ILFP2 ILFP
g yearR=max(1997, min(2055,year+(60-edad))) if edad>0 & edad<.
replace yearR=year if yearR==.
sum yearR sexo
joinby sexo yearR using "$path_epf2\Chile_CELADE_lifeexpR.dta", unmatched(master) update
tab _merge
drop _merge

g income_potential=max(0,ytot_ind) 
replace income_potential = max(income_potential, income_male_spouse, income_male_spouse_pot) if sexo==1
replace income_potential = max(income_potential, income_female_spouse, income_female_spouse_pot) if sexo==2
replace income_potential = max(income_potential, ingreso_trabajo)
sum income_potential ytot_ind ingreso_trabajo
pwcorr income_potential ytot_ind ingreso_trabajo
local GRs1_ed1 = 0.0132		// Men
local GRs1_ed2 = 0.0072 
local GRs1_ed3 = 0.0180
local GRs2_ed1 = 0.0168     // Women
local GRs2_ed2 = 0.0080
local GRs2_ed3 = 0.0216
g GRw=0
forvalues ed = 1/3 {
replace GRw = `GRs1_ed`ed'' if sexo==1 & educ==`ed'  // male_dummy==1
replace GRw = `GRs2_ed`ed'' if sexo==2 & educ==`ed'  //female_dummy
}
sum ILFP2 LFP2 PCS_Men_P1 PCS_Men_P0 PCS_Men_PSS  PCS_Men_P1_I1 PCS_Men_P1_I0 PCS_Men_P1_ISS desem unemp_sect pr_unemp pr_layoffs layoffs_sect rr_inc rr_inc_sect
egen RRInc = rowmax(rr_inc rr_inc_sect) 
g UnP = pr_unemp   // egen UnP = rowmax(unemp_sect pr_unemp) almost same as pr_unemp
replace UnP = min(unemp_sect, UnP) if UnP>0.15
sum RRInc UnP unemp_sect pr_unemp pr_layoffs layoffs_sect rr_inc rr_inc_sect
pwcorr RRInc UnP unemp_sect pr_unemp pr_layoffs layoffs_sect rr_inc rr_inc_sect
g LabE = max(0, income_potential*(1-UnP + UnP*RRInc))
g PCS=.
replace PCS=PCS_Men_P1_I1 if sexo==1 & ILFP2==1 & LFP2==1
replace PCS=PCS_Men_P1_I0 if sexo==1 & ILFP2==0 & LFP2==1
replace PCS=PCS_Men_P0 if sexo==1 & ILFP2==0 & LFP2==0
replace PCS=PCS_Men_P1_ISS if sexo==1 & ILFP2==1 & PCS==.
replace PCS=min(PCS_Men_PSS,PCS_Men_P1_ISS) if sexo==1 & PCS==.
replace PCS=PCS_Women_P1_I1 if sexo==2 & ILFP2==1 & LFP2==1
replace PCS=PCS_Women_P1_I0 if sexo==2 & ILFP2==0 & LFP2==1
replace PCS=PCS_Women_P0 if sexo==2 & ILFP2==0 & LFP2==0
replace PCS=PCS_Women_P1_ISS if sexo==2 & ILFP2==1 & PCS==.
replace PCS=min(PCS_Women_PSS,PCS_Women_P1_ISS) if sexo==2 & PCS==.
replace PCS=0 if PCS==.
g PCSemp=PCS*(1-UnP)
g ExpPCSemp=PCSemp*${wlife}
g prob_20y = binomialtail(${wlife},20,PCSemp)
g Future_retirees = 1 if parentesco<=3  // 1 Household Head, 2 spouse, 3 civil partner
replace Future_retirees = . if parentesco>=3 & year<2006
g death_age = max(1+edad, 60+life_expectancy60R)    //g death_age = 60+life_expectancy60 
sum CBeta* if a1==1 //g CBeta = (1-${discount_factor})/(1- ${discount_factor}^(life_expectancy0-edad)) if edad>=25 & edad<=life_expectancy0
pwcorr CBeta* if a1==1
replace CBeta = (1-${discount_factor})/(1-${discount_factor}^(1+max(life_expectancy0,edad)-edad)) //if edad>=25 & edad<=life_expectancy0
g var0 = min(${tope_2013}, LabE)*PCS
bysort folio_hogar: egen PCSLabEhh=total(var0)
drop var0

g edad_jh0 = edad
bysort folio_hogar: egen edad_jh=max(edad_jh)
drop if edad_jh<=24   //edad<=24   //keep if Future_retirees==1
drop edad_jh0
local age_Rw = ${R}-5
if ${Ewave}>=1950 {
keep if year>=${Ewave} 
}
g Life_last_income = exp((50-${blife})*GRw)       // local wlife=${R}-${blife}
g Life_mean_income = (1/2)*( Life_last_income + 1)
replace Life_mean_income = ( (1+${R}-50)*Life_last_income + (50-${blife})*(Life_mean_income) )*(1/(1+${R}-${blife}))
replace Life_last_income = Life_last_income*max(0, income_potential)
replace Life_mean_income = Life_mean_income*max(0, income_potential)    // g LabE = max(0, income_potential*(1-UnP + UnP*RRInc)) 

global pcr_fut=${pcrate}
Pension_Future ${R} `age_Rw' ${pcrate} ${tope_2013} 0
do "$path_epf\format_codes\Retiro_AFP.do"
foreach x of varlist PW_NoSy-TW_hh {
rename `x' B0_`x'     // Baseline variables 2019
}
g year0 = year
replace year=2022  //2020
Pension_Future ${R} `age_Rw' ${pcrate} ${tope_2013} 1   // end of 2022 scenario
Pension_Reparto ${R} ${tope_2013} 0.01 1
Pension_Reparto ${R} ${tope_2013} 0.01 2  //Reparto options 1 and 2 have same exact mean for 2017 and 2007, almost exact for 1997 (0.01 pesos difference) and 2012 (3 pesos diff)
Pension_Reparto ${R} ${tope_2013} 0.01 3  //replace APS_Reparto3=min(APS_Reparto3,APS_Reparto2) if APS_Reparto2>0 & APS_Reparto2<.
Pension_Reparto ${R} ${tope_2013} 0.01 4
sum APS* Impuestos if a1==1, d // Appears to work!!
foreach x of varlist PW_NoSy-Impuestos4 {
rename `x' B_`x'      // Baseline variables 2022
}
sum B_FE_hh-B_TW_hh if a1==1, d

global pcr_fut=${pcrate}+0.06
local R_Sall=67    
local agef_Sall=67
forv s=1/5 {
local tope_S`s'=${tope_2013}
}
local pcr_S1=${pcrate}
local Spcr_S1=0.00          //    //
local pcr_S2=${pcrate}+0.06
local Spcr_S2=0.00          //    //
local pcr_S3=${pcrate}+0.05
local Spcr_S3=0.01          //    //
local pcr_S4=${pcrate}+0.04
local Spcr_S4=0.02          //    //
local pcr_S5=${pcrate}+0.03
local Spcr_S5=0.03          //    //
local pcr_S6=${pcrate}+0.05
local Spcr_S6=0.01        
local tope_S6=10000000     //    //
local pcr_S7=${pcrate}+0.03
local Spcr_S7=0.03        
local tope_S7=10000000     //    //
forv s=1/7 {   // S scenarios
Pension_Future `R_Sall' `agef_Sall' `pcr_S`s'' `tope_S`s'' 1
if `s'>=3 {   // Scenarios with Reparto
forv op = 1/4 {
Pension_Reparto `R_Sall' `tope_S`s'' `Spcr_S`s'' `op'
}
}
capture g Impuestos4 = 0
foreach x of varlist PW_NoSy-Impuestos4 {
rename `x' S`s'_`x'     // S scenario variables
}
}
replace year=year0
drop year0
keep folio_hogar a1 ${factor_op} edad educ sexo quintile_h educ_ecf ILFP2 PCS PCSemp gasto_total numh parentesco CBeta year ///
income_potential-edad_jh Life_*inc* B0_PW_NoSy-S7_Impuestos4
save "$path4b\PensionScen_${Ewave}_allMembers.dta", replace
keep if a1==1
save "$path4b\PensionScen_${Ewave}.dta", replace
