pr def Pension_Reparto
    args age_R tope pcrep op

quietly {  // https://www.ips.gob.cl/servlet/internet/content/1421810823272/pension-basica-solidaria-vejez
local FwD = 1/${discount_factor}
local Rir = `FwD'-1
g ret_yr = max(2022, year+max(0,(`age_R'-edad)))  // assume 2022 is the earliest year for Reparto 
sum ret_yr
local yr1=r(min)
g death_yr = year+max(0,60+life_expectancy60R-`age_R')
local yr2=r(max)
g RepInc = `pcrep'*min(`tope',LabE) if Future_retirees==1 & edad>=25 & edad<=`age_R'
rename grupo_edad2 or_grupo_edad2
local minW=326500*(22783/28844)   // Minimum wage for 2020 in 2012 pesos

g PBS_Reparto = 0
forvalues yr=`yr1'(1)`yr2' {
capture drop YearR PopEdSexo
g grupo_edad2 = ceil(min(101,(1+edad))/5) if edad>=0 
g edad_yr = edad+(`yr'-year)
g YearR=`yr'
joinby YearR sexo grupo_edad2 using "$path_epf2\Chile_PopR.dta", unmatched(master) update    //tab _merge
g new_weights = ceil(${factor_op}*PopEdSexo)   // weights for workers
sum RepInc [fw=new_weights], d
local RepSum=r(sum)
drop _merge new_weights PopEdSexo   // weights for retirees
replace grupo_edad2 = ceil(min(101,(1+edad_yr))/5) if edad>=0 
joinby YearR sexo grupo_edad2 using "$path_epf2\Chile_PopR.dta", unmatched(master) update   //tab _merge
g new_weights = ceil(${factor_op}*PopEdSexo)  //  end weights for retirees
*xtile PindQ = m_pension if ret_yr<=`yr' & m_pension<. & Future_retirees==1 & edad_yr<=death_age [fw=new_weights], nq(5)
*xtile PFamQ0 = m_pension_hh if ret_yr<=`yr' & m_pension_hh<. & Future_retirees==1 & edad_yr<=death_age [fw=new_weights], nq(5)
xtile PFamQ0 = ytot_p_h if a1==1 [fw=new_weights], nq(5)
bysort folio_hogar: egen PFamQ = max(PFamQ0)
g dummyAPS = (m_pension<=`minW' & PFamQ<=3) if ret_yr<=`yr' & m_pension<. & Future_retirees==1 & edad_yr<=death_age  //g dummyAPS = (PindQ<=2 & PFamQ<=3) 
sum dummyAPS [fw=new_weights]
local RepNr=r(sum)
g year_pension0 = `yr'-2020
if `op'==1 {   //replace PBS_Reparto = dummyAPS*(`RepSum'/`RepNr') if dummyAPS==1 & ret_yr<=`yr' (Not right! because Reparto will fall as time goes on)
g BenRep = `RepSum'/`RepNr' if dummyAPS==1
}
if `op'==2 {  // RepSum=Sum(MP-(i-1)*a) gives RepSum=NR*MP-NR*(NR-1)*a/2 which gives MP=(RepSum/NR)+(NR-1)*a/2
egen i2 = rank(-m_pension) if dummyAPS==1, unique
sum dummyAPS 
local RepNr2=r(sum)  // option 1 and 2 give exact same average and total sum ( RepNr2 is necessary for expansion factors that are larger than 1 or non-constant)
local MP = (`RepSum'/`RepNr') + ((`RepNr2'-1)/2)  // local MP = (`RepSum'/`RepNr') + ((`RepNr'-1)/2)  (exact with expansion factor equal to 1) 
g BenRep = max(0,`MP'-(i2-1)) if dummyAPS==1   
}
if `op'==3 { // Same as option 2, but with stronger reach (3 quintiles of pensions and 4 quintiles of households)
local minW2=(1.01^(`yr'-2022))*`minW'
replace dummyAPS = (m_pension<=`minW2' & PFamQ<=4) if ret_yr<=`yr' & m_pension<. & Future_retirees==1 & edad_yr<=death_age //replace dummyAPS = (PindQ<=3 & PFamQ<=4) 
sum dummyAPS [fw=new_weights]
local RepNr=r(sum)
egen i2 = rank(-m_pension) if dummyAPS==1, unique
sum dummyAPS 
local RepNr2=r(sum) 
local MP = (`RepSum'/`RepNr') + ((`RepNr2'-1)/2) 
g BenRep = max(0,`MP'-(i2-1)) if dummyAPS==1
}   
if `op'==4 { // Same as option 2, but the subsidies are non-decreasing over time and financed by other Taxes
egen i2 = rank(-m_pension) if dummyAPS==1, unique
sum dummyAPS 
local RepNr2=r(sum)  // option 1 and 2 give exact same average and total sum ( RepNr2 is necessary for expansion factors that are larger than 1 or non-constant)
local MP = (`RepSum'/`RepNr') + ((`RepNr2'-1)/2)  // local MP = (`RepSum'/`RepNr') + ((`RepNr'-1)/2)  (exact with expansion factor equal to 1) 
g BenRep = max(0,`MP'-(i2-1)) if dummyAPS==1  
if `yr'>`yr1' {
replace BenRep = max(BenRep,BenRep_lastyr) if dummyAPS==1  
if `yr'==1+`yr1' {
g Impuestos=0
}
replace Impuestos = Impuestos + (${discount_factor}^year_pension0)*max(0, BenRep-max(0,`MP'-(i2-1)) ) if dummyAPS==1
drop BenRep_lastyr
}
g BenRep_lastyr = BenRep
}   
replace PBS_Reparto = PBS_Reparto + (${discount_factor}^year_pension0)*max(0, dummyAPS*BenRep) 
drop grupo_edad2-BenRep
}
capture drop YearR PopEdSexo
rename or_grupo_edad2 grupo_edad2   // replace PBS_Reparto = max(0, PBS_Reparto) + max(0, PW_APS) (not necessary)

bysort folio_hogar: egen APS_Reparto`op' = total(PBS_Reparto) 
g edad_r0 = max(0,`age_R'-edad)
g year_pension0 = (1+death_age-`age_R')
g PWFutind = (`FwD'^edad_r0)*max(0, PBS_Reparto)
g m_pension_totR`op' = (`Rir'/(1-`FwD'^(-year_pension0)))*PWFutind
replace m_pension_totR`op' =  max(0, m_pension_totR`op')+max(0,m_pension_tot) 
bysort folio_hogar: egen m_pension_totR`op'_hh = total(m_pension_totR`op')   
if `op'==4 { 
bysort folio_hogar: egen Impuestos`op' = total(Impuestos)
drop BenRep_lastyr Impuestos
}
if `pcrep'<=0.000001  {
replace APS_Reparto`op'=0
capture replace Impuestos`op'=0
}
capture drop ret_yr-PBS_Reparto edad_r0-PWFutind
}
end
