// Estimates equivalence measures for each type of household from the EPF family's income and consumption data
noisily {
if ${print_regs}==1 {  // Print regressions
capture log close
log using "$path4b\epf_equivalence_c_${year_epf}.log", replace 
}
//
use "$path4b\expenditures_${data_save_emp}.dta", clear
capture drop gasto_tot gasto_durable gasto_no_durable
g gasto_tot = consumo_total
g gasto_durable = Durable
g gasto_no_durable = consumo_NDur_Ser_SDur  //consumo_NDur_Ser
drop if pco1!=1        // unemp_rr_sect unemp_sect rr_inc_sect sd_ln_inc_sect
*recode grupo_edad 0/4=1 5/9=2 10/14=3 15/19=4 20/24=5 25/29=6 30/34=7 35/39=8 ///
*       40/44=9 45/49=10 50/54=11 55/59=12 60/64=13 65/69=14 70/74=15 75/.=16
drop if grupo_edad==.
drop if grupo_edad<=5
drop if grupo_edad>=14
drop if tr_edad2==.  // educacion_gasto gtos_medicos gtos_financieros dividendos
sum gasto_tot gasto_durable gasto_no_durable Durable Semi_Durable consumo_Ser No_Durable [fw=${factor_op}], d
sum unemp_sect rr_inc_sect sd_ln_inc_sect, d
g desem2 = desem
g unemp_rr_sect = unemp_sect*(1-rr_inc_sect)

local cond_vars "zona2 num_adul num_men num_sen grupo_edad" // tr_edad2 vivprop   desem2 tedu quintile_h 
local cond_vars_2 "zona2 num_adul num_men num_sen grupo_edad" // tr_edad2 vivprop   desem2 tedu quintile_h 
local cond_vars2 "zona2##num_adul##num_men##num_sen" // tedu quintile_h 
local cond_vars3 "zona2 num_adul num_men num_sen tr_edad2" // vivprop   desem2 desem tedu quintile_h 
sum tr_edad2
local min_age = r(min)
local max_age = r(max)
drop ytoth 
sum ytoth_cons if ytoth_cons>0
replace ytoth_cons = log( ytoth_cons + abs(r(min)) + 1000 )
g ytoth = ytoth_cons
quietly {
foreach x in unemp_sect sd_ln_inc_sect rr_inc_sect unemp_rr_sect {
sum `x' if  `x'>0, d
replace `x' = max( r(min),  `x' ) if `x'<.
replace `x' = min( r(p95),  `x' ) if `x'<.
*replace `x' = 0 if desem2==1
replace `x' = 0 if desem2==.
}
}
sum unemp_sect rr_inc_sect sd_ln_inc_sect, d
sum zona2 sexo sector_ind tedu educ tr_edad quintile_h
tab quintile_h
tab educ
tab sector_ind
tab tr_edad
*replace unemp_rr_sect = rr_inc_sect if desem2==1
*replace unemp_rr_sect = ln( unemp_rr_sect + abs(r(min)) + 1 ) if desem2==0
sum unemp_rr_sect if unemp_rr_sect>0

sum gasto* *sect
pwcorr gasto* *sect
pwcorr gasto* *sect [fw=${factor_op}]

foreach var_c in tot durable no_durable {
g pir_`var_c' = gasto_`var_c'/exp(ytoth_cons)
sum pir_`var_c', d
g pir2_`var_c' = pir_`var_c'
sum gasto_`var_c'
replace gasto_`var_c' = log( gasto_`var_c' + abs(r(min)) + 1000 )

foreach per_c in 50 {  // 25 50 75
pctile_wgts equi_c_`var_c'_p`per_c' gasto_`var_c' "`cond_vars'" ${factor_op} `per_c'
sum equi_c_`var_c'_p`per_c' [fw=${factor_op}], d
replace equi_c_`var_c'_p`per_c' = max(r(p5), equi_c_`var_c'_p`per_c')
replace equi_c_`var_c'_p`per_c' = min(r(p95), equi_c_`var_c'_p`per_c')
}
g gasto_`var_c'_dm = gasto_`var_c' - equi_c_`var_c'_p50
sum gasto_`var_c'_dm [fw=${factor_op}], d
bysort `cond_vars3': egen max_obs = pctile(gasto_`var_c'_dm), p(95)
bysort `cond_vars3': egen min_obs = pctile(gasto_`var_c'_dm), p(5)
replace gasto_`var_c'_dm = min(gasto_`var_c'_dm, max_obs) if gasto_`var_c'_dm<.
replace gasto_`var_c'_dm = max(gasto_`var_c'_dm, min_obs) if gasto_`var_c'_dm<.

// I shut down this loop for age coefficients
local vars_reg "i.(tr_edad2)#c.(ytoth sd_ln_inc_sect)" // "ytoth sd_ln_inc_sect" // other vars: unemp_rr_sect unemp_sect rr_inc_sect //ytoth_cons ytot_p_h ytoth ytoth_pi_exp
*forv age_k= `min_age'/`max_age' {
*reg gasto_`var_c' ytoth sd_ln_inc_sect if tr_edad2==`age_k' & gasto_`var_c'>=min_obs & gasto_`var_c'<=max_obs [fw=${factor_op}]
reg gasto_`var_c'_dm `vars_reg', vce(robust) //if gasto_`var_c'_dm>=min_obs & gasto_`var_c'_dm<=max_obs
reg gasto_`var_c'_dm `vars_reg' [pw=${factor_op}]    //[pw=${factor_op}], vce(jackknife, nodots)
reg gasto_`var_c' `vars_reg' i.(`cond_vars_2'), vce(robust)
reg gasto_`var_c' `vars_reg' i.(`cond_vars_2') [pw=${factor_op}]    //[pw=${factor_op}], vce(jackknife, nodots)
//
drop min_obs max_obs  //equi_c_`var_c'_p75 equi_c_`var_c'_p25 
}
keep ${factor_op} gasto_* equi_c_* `cond_vars' pir_* pir2_*
collapse (mean)  equi_c_*_p50 (p75) pir_* (p90) pir2_* [fw=${factor_op}], by(`cond_vars')
save "$path4b\equi_c_${data_save_emp}.dta", replace
g year =${year_epf}
save "$path4b\equi_c_${data_save_emp}_${year_epf}.dta", replace
//
if ${print_regs}==1 {  // Print regressions
capture log close
}
}
//
